@@ -1,4 +1,4 @@
 #!/usr/bin/python
 # -*- coding: utf8 -*-
-import py_dumpfs
-py_dumpfs.main()
+import pydumpfs
+pydumpfs.main()
